Struct msp430_atomic::AtomicPtr
source · [−]pub struct AtomicPtr<T> { /* private fields */ }Expand description
A raw pointer type which can be safely shared between threads.
This type has the same in-memory representation as a *mut T.
Implementations
Creates a new AtomicPtr.
Examples
use msp430_atomic::AtomicPtr;
let ptr = &mut 5;
let atomic_ptr = AtomicPtr::new(ptr);Returns a mutable reference to the underlying pointer.
This is safe because the mutable reference guarantees that no other threads are concurrently accessing the atomic data.
Examples
use msp430_atomic::AtomicPtr;
let mut atomic_ptr = AtomicPtr::new(&mut 10);
*atomic_ptr.get_mut() = &mut 5;
assert_eq!(unsafe { *atomic_ptr.load() }, 5);Consumes the atomic and returns the contained value.
This is safe because passing self by value guarantees that no other threads are
concurrently accessing the atomic data.
Examples
use msp430_atomic::AtomicPtr;
let atomic_ptr = AtomicPtr::new(&mut 5);
assert_eq!(unsafe { *atomic_ptr.into_inner() }, 5);Loads a value from the pointer.
Examples
use msp430_atomic::AtomicPtr;
let ptr = &mut 5;
let some_ptr = AtomicPtr::new(ptr);
let value = some_ptr.load();