Struct msp430_atomic::AtomicPtr [−][src]
pub struct AtomicPtr<T> { /* fields omitted */ }Expand description
A raw pointer type which can be safely shared between threads.
This type has the same in-memory representation as a *mut T.
Implementations
impl<T> AtomicPtr<T>[src]
impl<T> AtomicPtr<T>[src]pub const fn new(p: *mut T) -> AtomicPtr<T>[src]
pub const fn new(p: *mut T) -> AtomicPtr<T>[src]Creates a new AtomicPtr.
Examples
use msp430_atomic::AtomicPtr; let ptr = &mut 5; let atomic_ptr = AtomicPtr::new(ptr);
pub fn get_mut(&mut self) -> &mut *mut T[src]
pub fn get_mut(&mut self) -> &mut *mut T[src]Returns a mutable reference to the underlying pointer.
This is safe because the mutable reference guarantees that no other threads are concurrently accessing the atomic data.
Examples
use msp430_atomic::AtomicPtr; let mut atomic_ptr = AtomicPtr::new(&mut 10); *atomic_ptr.get_mut() = &mut 5; assert_eq!(unsafe { *atomic_ptr.load() }, 5);
pub fn into_inner(self) -> *mut T[src]
pub fn into_inner(self) -> *mut T[src]Consumes the atomic and returns the contained value.
This is safe because passing self by value guarantees that no other threads are
concurrently accessing the atomic data.
Examples
use msp430_atomic::AtomicPtr; let atomic_ptr = AtomicPtr::new(&mut 5); assert_eq!(unsafe { *atomic_ptr.into_inner() }, 5);